@@ -825,7 +825,7 @@ ShpLoaderCreate(SHPLOADERCONFIG *config)
 
 	if (!state->geo_col)
 	{
-		state->geo_col = strdup(config->geography ? GEOGRAPHY_DEFAULT : GEOMETRY_DEFAULT);
+		state->geo_col = config->geography ? GEOGRAPHY_DEFAULT : GEOMETRY_DEFAULT;
 	}
 
 	colmap_init(&state->column_map);
@@ -845,7 +845,7 @@ ShpLoaderOpenShape(SHPLOADERSTATE *state)
 	int field_precision, field_width;
 	char name[MAXFIELDNAMELEN];
 	char name2[MAXFIELDNAMELEN];
-	DBFFieldType type = -1;
+	DBFFieldType type = FTInvalid;
 	char *utf8str;
 
 	/* If we are reading the entire shapefile, open it */
@@ -1100,9 +1100,9 @@ ShpLoaderOpenShape(SHPLOADERSTATE *state)
 	state->pgfieldtypes = malloc(state->num_fields * sizeof(char *));
 	state->col_names = malloc((state->num_fields + 2) * sizeof(char) * MAXFIELDNAMELEN);
 
-	/* Generate a string of comma separated column names of the form "(col1, col2 ... colN)" for the SQL
+	strcpy(state->col_names, "" );
+	/* Generate a string of comma separated column names of the form "col1, col2 ... colN" for the SQL
 	   insertion string */
-	strcpy(state->col_names, "(" );
 
 	for (j = 0; j < state->num_fields; j++)
 	{
@@ -1270,9 +1270,6 @@ ShpLoaderOpenShape(SHPLOADERSTATE *state)
 	if (state->config->readshape == 1)
 		strcat(state->col_names, state->geo_col);
 
-	strcat(state->col_names, ")");
-
-
 	/* Return status */
 	return ret;
 }
@@ -1367,10 +1364,9 @@ ShpLoaderGetSQLHeader(SHPLOADERSTATE *state, char **strheader)
 			/* First output the raw field type string */
 			stringbuffer_aprintf(sb, "%s", state->pgfieldtypes[j]);
 
-			/* Some types do have typmods */
-			/* Apply width typmod for varchar if there is positive width **/
-			if (!strcmp("varchar", state->pgfieldtypes[j]) && state->widths[j] > 0)
-					stringbuffer_aprintf(sb, "(%d)", state->widths[j]);
+			/* Some types do have typmods though... */
+			if (!strcmp("varchar", state->pgfieldtypes[j]))
+				stringbuffer_aprintf(sb, "(%d)", state->widths[j]);
 
 			if (!strcmp("numeric", state->pgfieldtypes[j]))
 			{
@@ -1391,13 +1387,11 @@ ShpLoaderGetSQLHeader(SHPLOADERSTATE *state, char **strheader)
 			else
 				dimschar = "";
 
-			if (state->to_srid != SRID_UNKNOWN && state->to_srid != 4326)
-			{
-				snprintf(state->message, SHPLOADERMSGLEN, _("Invalid SRID for geography type: %d"), state->to_srid);
-				stringbuffer_destroy(sb);
-				return SHPLOADERERR;
+			if (state->to_srid == SRID_UNKNOWN ){
+				state->to_srid = 4326;
 			}
-			stringbuffer_aprintf(sb, ",\n\"%s\" geography(%s%s,%d)", state->geo_col, state->pgtype, dimschar, 4326);
+
+			stringbuffer_aprintf(sb, ",\n\"%s\" geography(%s%s,%d)", state->geo_col, state->pgtype, dimschar, state->to_srid);
 		}
 		stringbuffer_aprintf(sb, ")");
 
@@ -1449,7 +1443,7 @@ ShpLoaderGetSQLHeader(SHPLOADERSTATE *state, char **strheader)
 		if (state->config->readshape == 1 && (!state->config->geography))
 		{
 			/* If they didn't specify a target SRID, see if they specified a source SRID. */
-			int srid = state->to_srid;
+			int32_t srid = state->to_srid;
 			if (state->config->schema)
 			{
 				stringbuffer_aprintf(sb, "SELECT AddGeometryColumn('%s','%s','%s','%d',",
@@ -1465,6 +1459,22 @@ ShpLoaderGetSQLHeader(SHPLOADERSTATE *state, char **strheader)
 		}
 	}
 
+	/**If we are in dump mode and a transform was asked for need to create a temp table to store original data
+	 You may ask, why don't we go straight into the main table and then do an alter table alter column afterwards
+	 Main reason is so we don't incur the penalty of WAL logging when we change the typmod in final run. **/
+	if (state->config->dump_format && state->to_srid != state->from_srid){
+		/** create a temp table with same structure as main except for no restriction on geometry type */
+		stringbuffer_aprintf(sb, "CREATE TEMP TABLE \"pgis_tmp_%s\" AS SELECT * FROM ", state->config->table);
+		/* Schema is optional, include if present. */
+		if (state->config->schema)
+		{
+			stringbuffer_aprintf(sb, "\"%s\".",state->config->schema);
+		}
+		stringbuffer_aprintf(sb, "\"%s\" WHERE false;\n", state->config->table, state->geo_col);
+		/**out input data is going to be in different srid from target, so need to remove type constraint **/
+		stringbuffer_aprintf(sb, "ALTER TABLE \"pgis_tmp_%s\" ALTER COLUMN \"%s\" TYPE geometry USING ( (\"%s\"::geometry) ); \n", state->config->table,  state->geo_col, state->geo_col);
+	}
+
 	/* Copy the string buffer into a new string, destroying the string buffer */
 	ret = (char *)malloc(strlen((char *)stringbuffer_getstring(sb)) + 1);
 	strcpy(ret, (char *)stringbuffer_getstring(sb));
@@ -1480,27 +1490,37 @@ ShpLoaderGetSQLHeader(SHPLOADERSTATE *state, char **strheader)
 int
 ShpLoaderGetSQLCopyStatement(SHPLOADERSTATE *state, char **strheader)
 {
-	char *copystr;
+	//char *copystr;
+	stringbuffer_t *sb;
+	char *ret;
+	sb = stringbuffer_create();
+	stringbuffer_clear(sb);
+
 
 	/* Allocate the string for the COPY statement */
 	if (state->config->dump_format)
 	{
-		if (state->config->schema)
-		{
-			copystr = malloc(strlen(state->config->schema) + strlen(state->config->table) +
-			                 strlen(state->col_names) + 40);
+		stringbuffer_aprintf(sb, "COPY ");
 
-			sprintf(copystr, "COPY \"%s\".\"%s\" %s FROM stdin;\n",
-			        state->config->schema, state->config->table, state->col_names);
+		if (state->to_srid != state->from_srid){
+			/** if we need to transform we copy into temp table instead of main table first */
+			stringbuffer_aprintf(sb, " \"pgis_tmp_%s\" (%s) FROM stdin;\n", state->config->table, state->col_names);
 		}
-		else
-		{
-			copystr = malloc(strlen(state->config->table) + strlen(state->col_names) + 40);
+		else {
+			if (state->config->schema)
+			{
+				stringbuffer_aprintf(sb, " \"%s\".", state->config->schema);
+			}
 
-			sprintf(copystr, "COPY \"%s\" %s FROM stdin;\n", state->config->table, state->col_names);
+			stringbuffer_aprintf(sb, "\"%s\" (%s) FROM stdin;\n", state->config->table, state->col_names);
 		}
 
-		*strheader = copystr;
+		/* Copy the string buffer into a new string, destroying the string buffer */
+		ret = (char *)malloc(strlen((char *)stringbuffer_getstring(sb)) + 1);
+		strcpy(ret, (char *)stringbuffer_getstring(sb));
+		stringbuffer_destroy(sb);
+
+		*strheader = ret;
 		return SHPLOADEROK;
 	}
 	else
@@ -1573,12 +1593,12 @@ ShpLoaderGenerateSQLRowStatement(SHPLOADERSTATE *state, int item, char **strreco
 	{
 		if (state->config->schema)
 		{
-			stringbuffer_aprintf(sb, "INSERT INTO \"%s\".\"%s\" %s VALUES (", state->config->schema,
+			stringbuffer_aprintf(sb, "INSERT INTO \"%s\".\"%s\" (%s) VALUES (", state->config->schema,
 			                     state->config->table, state->col_names);
 		}
 		else
 		{
-			stringbuffer_aprintf(sb, "INSERT INTO \"%s\" %s VALUES (", state->config->table,
+			stringbuffer_aprintf(sb, "INSERT INTO \"%s\" (%s) VALUES (", state->config->table,
 			                     state->col_names);
 		}
 	}
@@ -1623,6 +1643,14 @@ ShpLoaderGenerateSQLRowStatement(SHPLOADERSTATE *state, int item, char **strreco
 
 			case FTString:
 			case FTLogical:
+				rv = snprintf(val, MAXVALUELEN, "%s", DBFReadStringAttribute(state->hDBFHandle, item, i));
+				if (rv >= MAXVALUELEN || rv == -1)
+				{
+					stringbuffer_aprintf(sbwarn, "Warning: field %d name truncated\n", i);
+					val[MAXVALUELEN - 1] = '\0';
+				}
+				break;
+
 			case FTDate:
 				rv = snprintf(val, MAXVALUELEN, "%s", DBFReadStringAttribute(state->hDBFHandle, item, i));
 				if (rv >= MAXVALUELEN || rv == -1)
@@ -1630,6 +1658,14 @@ ShpLoaderGenerateSQLRowStatement(SHPLOADERSTATE *state, int item, char **strreco
 					stringbuffer_aprintf(sbwarn, "Warning: field %d name truncated\n", i);
 					val[MAXVALUELEN - 1] = '\0';
 				}
+				if (strlen(val) == 0)
+				{
+					if (state->config->dump_format)
+						stringbuffer_aprintf(sb, "\\N");
+					else
+						stringbuffer_aprintf(sb, "NULL");
+					goto done_cell;
+				}
 				break;
 
 			default:
@@ -1689,6 +1725,8 @@ ShpLoaderGenerateSQLRowStatement(SHPLOADERSTATE *state, int item, char **strreco
 				free(escval);
 		}
 
+done_cell:
+
 		/* Only put in delimeter if not last field or a shape will follow */
 		if (state->config->readshape == 1 || i < DBFGetFieldCount(state->hDBFHandle) - 1)
 		{
@@ -1846,6 +1884,25 @@ ShpLoaderGetSQLFooter(SHPLOADERSTATE *state, char **strfooter)
 	sb = stringbuffer_create();
 	stringbuffer_clear(sb);
 
+	if ( state->config->dump_format && state->to_srid != state->from_srid){
+		/** We need to copy from the temp table to the real table, transforming to to_srid **/
+		stringbuffer_aprintf(sb, "ALTER TABLE  \"pgis_tmp_%s\" ALTER COLUMN \"%s\" TYPE ", state->config->table, state->geo_col);
+		if (state->config->geography){
+			stringbuffer_aprintf(sb, "geography USING (ST_Transform(\"%s\", %d)::geography );\n", state->geo_col, state->to_srid);
+		}
+		else {
+			stringbuffer_aprintf(sb, "geometry USING (ST_Transform(\"%s\", %d)::geometry );\n", state->geo_col, state->to_srid);
+		}
+		stringbuffer_aprintf(sb, "INSERT INTO ");
+		// /* Schema is optional, include if present. */
+		if (state->config->schema)
+		{
+			stringbuffer_aprintf(sb, "\"%s\".", state->config->schema);
+		}
+		stringbuffer_aprintf(sb, "\"%s\" (%s) ", state->config->table, state->col_names);
+		stringbuffer_aprintf(sb, "SELECT %s FROM \"pgis_tmp_%s\";\n", state->col_names, state->config->table);
+	}
+
 	/* Create gist index if specified and not in "prepare" mode */
 	if (state->config->readshape && state->config->createindex)
 	{
