@@ -30,7 +30,6 @@
 #include <float.h>
 #include <string.h>
 #include <stdio.h>
-#include <errno.h>
 #include <assert.h>
 
 #include "access/gist.h"
@@ -90,7 +89,7 @@ Datum LWGEOM_in(PG_FUNCTION_ARGS)
 	LWGEOM_PARSER_RESULT lwg_parser_result;
 	LWGEOM *lwgeom;
 	GSERIALIZED *ret;
-	int srid = 0;
+	int32_t srid = 0;
 
 	if ( (PG_NARGS()>2) && (!PG_ARGISNULL(2)) ) {
 		geom_typmod = PG_GETARG_INT32(2);
@@ -137,7 +136,7 @@ Datum LWGEOM_in(PG_FUNCTION_ARGS)
 		if ( srid ) lwgeom_set_srid(lwgeom, srid);
 		/* Add a bbox if necessary */
 		if ( lwgeom_needs_bbox(lwgeom) ) lwgeom_add_bbox(lwgeom);
-		pfree(wkb);
+		lwfree(wkb);
 		ret = geometry_serialize(lwgeom);
 		lwgeom_free(lwgeom);
 	}
@@ -323,7 +322,7 @@ Datum LWGEOM_asHEXEWKB(PG_FUNCTION_ARGS)
 	SET_VARSIZE(result, text_size);
 
 	/* Clean up and return */
-	pfree(hexwkb);
+	lwfree(hexwkb);
 	PG_FREE_IF_COPY(geom, 0);
 	PG_RETURN_TEXT_P(result);
 }
@@ -352,7 +351,7 @@ Datum LWGEOM_to_text(PG_FUNCTION_ARGS)
 
 	/* Copy into text obect */
 	result = cstring_to_text(hexwkb);
-	pfree(hexwkb);
+	lwfree(hexwkb);
 
 	/* Clean up and return */
 	PG_FREE_IF_COPY(geom, 0);
@@ -369,17 +368,18 @@ Datum LWGEOM_to_text(PG_FUNCTION_ARGS)
 PG_FUNCTION_INFO_V1(LWGEOMFromEWKB);
 Datum LWGEOMFromEWKB(PG_FUNCTION_ARGS)
 {
-	bytea *bytea_wkb = (bytea*)PG_GETARG_BYTEA_P(0);
-	int32 srid = 0;
+	bytea *bytea_wkb = PG_GETARG_BYTEA_P(0);
 	GSERIALIZED *geom;
 	LWGEOM *lwgeom;
 	uint8_t *wkb = (uint8_t*)VARDATA(bytea_wkb);
 
-	lwgeom = lwgeom_from_wkb(wkb, VARSIZE(bytea_wkb)-VARHDRSZ, LW_PARSER_CHECK_ALL);
+	lwgeom = lwgeom_from_wkb(wkb, VARSIZE_ANY_EXHDR(bytea_wkb), LW_PARSER_CHECK_ALL);
+	if (!lwgeom)
+		lwpgerror("Unable to parse WKB");
 
-	if (  ( PG_NARGS()>1) && ( ! PG_ARGISNULL(1) ))
+	if ((PG_NARGS() > 1) && (!PG_ARGISNULL(1)))
 	{
-		srid = PG_GETARG_INT32(1);
+		int32 srid = PG_GETARG_INT32(1);
 		lwgeom_set_srid(lwgeom, srid);
 	}
 
@@ -399,14 +399,14 @@ Datum LWGEOMFromEWKB(PG_FUNCTION_ARGS)
 PG_FUNCTION_INFO_V1(LWGEOMFromTWKB);
 Datum LWGEOMFromTWKB(PG_FUNCTION_ARGS)
 {
-	bytea *bytea_twkb = (bytea*)PG_GETARG_BYTEA_P(0);
+	bytea *bytea_twkb = PG_GETARG_BYTEA_P(0);
 	GSERIALIZED *geom;
 	LWGEOM *lwgeom;
 	uint8_t *twkb = (uint8_t*)VARDATA(bytea_twkb);
 
-	lwgeom = lwgeom_from_twkb(twkb, VARSIZE(bytea_twkb)-VARHDRSZ, LW_PARSER_CHECK_ALL);
+	lwgeom = lwgeom_from_twkb(twkb, VARSIZE_ANY_EXHDR(bytea_twkb), LW_PARSER_CHECK_ALL);
 
-	if ( lwgeom_needs_bbox(lwgeom) )
+	if (lwgeom_needs_bbox(lwgeom))
 		lwgeom_add_bbox(lwgeom);
 
 	geom = geometry_serialize(lwgeom);
@@ -444,7 +444,7 @@ Datum WKBFromLWGEOM(PG_FUNCTION_ARGS)
 			variant = variant | WKB_NDR;
 		}
 	}
-	wkb_size= VARSIZE(geom) - VARHDRSZ;
+	wkb_size= VARSIZE_ANY_EXHDR(geom);
 	/* Create WKB hex string */
 	lwgeom = lwgeom_from_gserialized(geom);
 
@@ -457,7 +457,7 @@ Datum WKBFromLWGEOM(PG_FUNCTION_ARGS)
 	SET_VARSIZE(result, wkb_size+VARHDRSZ);
 
 	/* Clean up and return */
-	pfree(wkb);
+	lwfree(wkb);
 	PG_FREE_IF_COPY(geom, 0);
 	PG_RETURN_BYTEA_P(result);
 }
@@ -561,13 +561,8 @@ Datum TWKBFromLWGEOMArray(PG_FUNCTION_ARGS)
 	/* Loop through array and build a collection of geometry and */
 	/* a simple array of ids. If either side is NULL, skip it */
 
-#if POSTGIS_PGSQL_VERSION >= 95
 	iter_geoms = array_create_iterator(arr_geoms, 0, NULL);
 	iter_ids = array_create_iterator(arr_ids, 0, NULL);
-#else
-	iter_geoms = array_create_iterator(arr_geoms, 0);
-	iter_ids = array_create_iterator(arr_ids, 0);
-#endif
 
 	while( array_iterate(iter_geoms, &val_geom, &null_geom) &&
 	       array_iterate(iter_ids, &val_id, &null_id) )
@@ -708,7 +703,7 @@ Datum LWGEOM_dropBBOX(PG_FUNCTION_ARGS)
 	if ( ! gserialized_has_bbox(geom) )
 		PG_RETURN_POINTER(geom);
 
-	PG_RETURN_POINTER(gserialized_drop_gidx(geom));
+	PG_RETURN_POINTER(gserialized_drop_gbox(geom));
 }
 
 
