@@ -46,14 +46,17 @@ PG_FUNCTION_INFO_V1(pgis_asgeobuf_transfn);
 Datum pgis_asgeobuf_transfn(PG_FUNCTION_ARGS)
 {
 #if ! (defined HAVE_LIBPROTOBUF && defined HAVE_GEOBUF)
-	elog(ERROR, "Missing libprotobuf-c >= version 1.1");
+	elog(ERROR, "ST_AsGeobuf: Missing libprotobuf-c >= version 1.1");
 	PG_RETURN_NULL();
 #else
 	MemoryContext aggcontext;
 	struct geobuf_agg_context *ctx;
 
+	/* We need to initialize the internal cache to access it later via postgis_oid() */
+	postgis_initialize_cache(fcinfo);
+
 	if (!AggCheckCallContext(fcinfo, &aggcontext))
-		elog(ERROR, "pgis_asmvt_transfn: called in non-aggregate context");
+		elog(ERROR, "pgis_asgeobuf_transfn: called in non-aggregate context");
 	MemoryContextSwitchTo(aggcontext);
 
 	if (PG_ARGISNULL(0)) {
@@ -83,7 +86,7 @@ PG_FUNCTION_INFO_V1(pgis_asgeobuf_finalfn);
 Datum pgis_asgeobuf_finalfn(PG_FUNCTION_ARGS)
 {
 #if ! (defined HAVE_LIBPROTOBUF && defined HAVE_GEOBUF)
-	elog(ERROR, "Missing libprotobuf-c >= version 1.1");
+	elog(ERROR, "ST_AsGeoBuf: Missing libprotobuf-c >= version 1.1");
 	PG_RETURN_NULL();
 #else
 	uint8_t *buf;
